==> abby-client-1.4.2.tgz: package/lib/sync.js <==
'use strict';
const rp = require('request-promise-native');

const ABBY_EXPERIMENTS_KEY = Symbol('__abbyExperiments');
const ABBY_TIMEOUT_KEY = Symbol('__abbyTimeout');
const ABBY_SYNC = Symbol('__abbySync');
const UPDATE_INTERVAL = 60000 * 1; // 1 minute
const logger = require('./logger').instance();

let load = async (/**Configs*/configs) => {
    try {
        let options = {
            uri: `${configs.apiEndpoint}/experiments`,
            qs: {
                tag: [configs.tags]
            },
            json: true
        };

        let /**Array.<Experiment>*/experiments = await rp(options);
        global[ABBY_EXPERIMENTS_KEY] = experiments;
        global[ABBY_SYNC] = new Date().toISOString();
        return experiments;
    } catch (e) {
        logger.error(`abby-client cannot load experiments: ${configs.apiEndpoint}, tags: ${configs.tags}`);
        return [];
    } finally {
        if (global[ABBY_TIMEOUT_KEY]) {
            clearTimeout(global[ABBY_TIMEOUT_KEY]);
        }
        let interval = typeof configs.update_interval === 'number' ? configs.update_interval : UPDATE_INTERVAL;
        global[ABBY_TIMEOUT_KEY] = setTimeout(() => load(configs), interval);
    }
};


let sync = {
    load
};

Object.defineProperty(sync, 'data', {
    get: () => {
        return Array.isArray(global[ABBY_EXPERIMENTS_KEY]) ? global[ABBY_EXPERIMENTS_KEY] : [];
    }
});

Object.defineProperty(sync, 'lastSync', {
    get: () => {
        return global[ABBY_SYNC];
    }
});

module.exports = sync;

==> abby-client-1.4.4.tgz: package/lib/sync.js <==
'use strict';
const rp = require('request-promise-native');

const ABBY_EXPERIMENTS_KEY = Symbol('__abbyExperiments');
const ABBY_TIMEOUT_KEY = Symbol('__abbyTimeout');
const ABBY_SYNC = Symbol('__abbySync');
const UPDATE_INTERVAL = 60000 * 1; // 1 minute
const logger = require('./logger').instance();

let load = async (/**Configs*/configs) => {
    try {
        let tags = configs.tags.forEach(tag => `tag=${tag}`).join('&');
        let options = {
            uri: `${configs.apiEndpoint}/experiments?active=true&${tags}`,
            json: true
        };

        let /**Array.<Experiment>*/experiments = await rp(options);
        global[ABBY_EXPERIMENTS_KEY] = experiments;
        global[ABBY_SYNC] = new Date().toISOString();
        return experiments;
    } catch (e) {
        logger.error(`abby-client cannot load experiments: ${configs.apiEndpoint}, tags: ${configs.tags}`);
        return [];
    } finally {
        if (global[ABBY_TIMEOUT_KEY]) {
            clearTimeout(global[ABBY_TIMEOUT_KEY]);
        }
        let interval = typeof configs.update_interval === 'number' ? configs.update_interval : UPDATE_INTERVAL;
        global[ABBY_TIMEOUT_KEY] = setTimeout(() => load(configs), interval);
    }
};


let sync = {
    load
};

Object.defineProperty(sync, 'data', {
    get: () => {
        return Array.isArray(global[ABBY_EXPERIMENTS_KEY]) ? global[ABBY_EXPERIMENTS_KEY] : [];
    }
});

Object.defineProperty(sync, 'lastSync', {
    get: () => {
        return global[ABBY_SYNC];
    }
});

module.exports = sync;
